function varargout = gui_default(action,object)
%
% Sets default values for graphical user interfaces
%
% gui_default('set')
%  sets matlab root properties 
%
% gui_default('remove')
%  removes matlab root properties 
%
% S = gui_default('geometry',object)
%  returns default geometry properties for specific objects
%  objects can be: 'figure', 'axes', 'uicontrol'
%
% Author:  Winfried Kernbichler
% Version: 1.0 
% Date:    October 17, 2001
% Status:  Workes very well in all tests at the moment
% Missing: Check of input

switch action
  case 'set'    % graphcon('initgraph_pre')
    set(0, 'DefaultFigureToolbar',        'none'      )  % keine Toolbar
    set(0, 'DefaultFigureMenubar',        'none'      )  % keine Menu's  
    set(0, 'DefaultFigureIntegerHandle',  'off'       )    
    set(0, 'DefaultFigureNumberTitle',    'off'       )  % keine Nummerierung der 'figures'  
    set(0, 'DefaultAxesFontUnits',        'normalized')  % legt Art der 'units' fest (Pixel, Normiert, etc.) 
    set(0, 'DefaultUicontrolUnits',       'normalized')    
    set(0, 'DefaultUicontrolFontUnits',   'normalized')
    set(0, 'DefaultAxesFontSize', 10, 'DefaultTextFontSize', 10)
  case 'remove'
    set(0, 'DefaultFigureToolbar',        'remove'    )
    set(0, 'DefaultFigureMenubar',        'remove'    )    
    set(0, 'DefaultFigureIntegerHandle',  'remove'    )    
    set(0, 'DefaultFigureNumberTitle',    'remove'    )    
    set(0, 'DefaultAxesFontUnits',        'remove'    )    
    set(0, 'DefaultUicontrolUnits',       'remove'    )    
    set(0, 'DefaultUicontrolFontUnits',   'remove'    )    
  case 'geometry' % aufruf von 'gui_define' (wandelt die Angaben von
                  % 'geometry' und 'frame' in 'position' um!
    switch object
      case 'figure'
	varargout{1} = struct( ...
	    'frame',     { [0.0, 0.0, 1.0, 1.0] }, ...
	    'geometry',  { [1] }, ...
	    'xborder',   { [50, 50] }, ...
	    'yborder',   { [50, 54] }, ...
	    'xgap',      { [12] }, ...
	    'ygap',      { [32] }, ...
	    'xedge',     { [0, 0] }, ...
	    'yedge',     { [0, 0] }, ...	    
	    'sizetot',   { get(0,'screensize') }, ...
	    'xsize',     { [300] }, ...
	    'ysize',     { [200] }, ...
	    'xshift',    { [0] }, ...
	    'yshift',    { [0] }, ...
	    'xmodify',   { 'size' }, ...
	    'ymodify',   { 'size' }, ...
	    'sizeunits', { 'pixels' } ...
	    );
      case 'axes'
	varargout{1} = struct( ...
	    'frame',     { [0.0, 0.0, 1.0, 1.0] }, ...
	    'geometry',  { [1] }, ...
	    'xborder',   { [0.1, 0.05] }, ...
	    'yborder',   { [0.1, 0.05] }, ...
	    'xgap',      { [0.1] }, ...
	    'ygap',      { [0.1] }, ...
	    'xedge',     { [0, 0] }, ...
	    'yedge',     { [0, 0] }, ...
	    'sizetot',   { [0,0,1,1] }, ...
	    'xsize',     { [0.85] }, ...
	    'ysize',     { [0.85] }, ...
	    'xshift',    { [0] }, ...
	    'yshift',    { [0] }, ...
	    'xmodify',   { 'size' }, ...
	    'ymodify',   { 'size' }, ...
	    'sizeunits', { 'normalized' } ...
	    );
      case 'uicontrol'
	varargout{1} = struct( ...
	    'frame',     { [0.0, 0.0, 1.0, 1.0] }, ...
	    'geometry',  { [1] }, ...
	    'xborder',   { [0.1, 0.1] }, ...
	    'yborder',   { [0.1, 0.1] }, ...
	    'xgap',      { [0.05] }, ...
	    'ygap',      { [0.05] }, ...
	    'xedge',     { [0, 0] }, ...
	    'yedge',     { [0, 0] }, ...
	    'sizetot',   { [0,0,1,1] }, ...
	    'xsize',     { [0.20] }, ...
	    'ysize',     { [0.20] }, ...
	    'xshift',    { [0] }, ...
	    'yshift',    { [0] }, ...
	    'xmodify',   { 'size' }, ...
	    'ymodify',   { 'size' }, ...
	    'sizeunits', { 'normalized' } ...
	    );
      otherwise
	error('gui_default: object not defined');
    end
    
  otherwise
    error('gui_default: case not defined');
end
