function [x, error, iter, flag]  = sor_disp(A, x, b, w, max_it, tol, h_axes,delay, varargin)

%  -- Iterative template routine --
%     Univ. of Tennessee and Oak Ridge National Laboratory
%     October 1, 1993
%     Details of this algorithm are described in "Templates for the
%     Solution of Linear Systems: Building Blocks for Iterative
%     Methods", Barrett, Berry, Chan, Demmel, Donato, Dongarra,
%     Eijkhout, Pozo, Romine, and van der Vorst, SIAM Publications,
%     1993. (ftp netlib2.cs.utk.edu; cd linalg; get templates.ps).
%  
%     modified for 'iteration display' by Christian Sommer
%  
% [x, error, iter, flag]  = sor(A, x, b, w, max_it, tol)
%
% sor.m solves the linear system Ax=b using the 
% Successive Over-Relaxation Method (Gauss-Seidel method when omega = 1 ).
%
% input   A           REAL matrix
%         x           REAL initial guess vector
%         b           REAL right hand side vector
%         w           REAL relaxation scalar
%         max_it      INTEGER maximum number of iterations
%         tol         REAL error tolerance
%         h_axes      Handle of the axes
%         delay   INTEGER number, number of skipped iterations
%         varargin: h_pop_plotmode = varargin{1};
%                   h_pop_col = varargin{2};
%                   h_pop_shad = varargin{3}
%                   X = varargin{4};     
%                   Y = varargin{5};
%                   index_in = varargin{7}
%                   h_stop = varargin{8}
%
%
% output  x        REAL solution vector
%         error    REAL error norm
%         iter     INTEGER number of iterations performed
%         flag     INTEGER: 0 = solution found to tolerance
%                           1 = no convergence given max_it

  flag = 0;                                   % initialization
  iter = 0;
  % stores the 'tag' of the 'axes', because 'highlevel' 'graphics'
  % set it to 'default'
  tag_axes = get(h_axes,'tag');
  
  % get 'graphics' 'value' and 'userdata' from the 'popup' menu
  h_pop_plotmode = varargin{1};
  h_pop_col = varargin{2};
  h_pop_shad = varargin{3};
  % coordinates of the 3d plot
  X = varargin{4};     
  Y = varargin{5};
  G = varargin{6};
  index_in = varargin{7};
  % 'stop' handle
  h_stop = varargin{8};
  
  
  
  % alle '0' im Gebiet werden 'NaN' gesetzt(uebersichtlichere Darstellung in den 'plots'
  Gnan=G;
  Gnan(find(G == 0)) = NaN;
  
  
  plot3d_nr = get(h_pop_plotmode,'value');
  plot3d_style_str = gui_get_userdata(h_pop_plotmode,'plotstyle_3d');
    
  % contain also the 'colorbar' 
  ev_str = strrep(plot3d_style_str(plot3d_nr,:),'##','Z');
  if plot3d_nr ~= 2
    ev_str_plot = strrep(ev_str,' h_cb = colorbar;','');
  else
    ev_str_plot = strrep(ev_str,' h_cb = [];','');
  end
 
  % get data form 'popup' 'Color 3D'
  col_nr = get(h_pop_col,'value');
  col_str = gui_get_userdata(h_pop_col,'color_3d');
  ev_str_col = col_str(col_nr,:);
  % get data form 'popup' 'Shading 3D'
  shad_nr = get(h_pop_shad,'value');
  shad_str = gui_get_userdata(h_pop_shad,'shading');
  ev_str_shad = shad_str(shad_nr,:);
  
  % set the 'axes' with the handle 'h_axes' to the current one
  axes(h_axes)
  
 % keyboard
  bnrm2 = norm( b );
  if  ( bnrm2 == 0.0 ), bnrm2 = 1.0; end

  r = b - A*x;
  error = norm( r ) / bnrm2;
  if ( error < tol ) return, end

  [ M, N, b ] = split( A, b, w, 2 );          % matrix splitting for 
  label_flag = 1;
  for iter = 1:max_it                         % begin iteration
    if ~mod(iter,delay)
       % create a row-vector of the length 'length(G)^2'
       Z = reshape(G,length(G)^2,1);    
       % stores the vector x at the position of 'index_in'
       Z(index_in) = x;
       % reshape 'Z' to the same dimension as 'G'
       Z = reshape(Z,length(G),length(G)).*Gnan;
       
       eval(ev_str_plot)
       eval(ev_str_col)
       eval(ev_str_shad)
       if label_flag == 1 
         title('Process of iteration','fontsize',12);
         xlabel('x','fontsize',12);
         ylabel('y','fontsize',12);
         zlabel('T_{iter} / C','fontsize',12);
	 label_flag == 0;
       end
       drawnow
     end
     stop_val = gui_get_userdata(h_stop,'stop');
     if stop_val, break; end
    
     x_1 = x;
     x   = M \ ( N*x + b );                   % update approximation
     
     error = norm( x - x_1 ) / norm( x );     % compute error
     if ( error <= tol ), break, end          % check convergence

  end
  b = b / w;                                  % restore rhs

  if ( error > tol ) flag = 1; end;           % no convergence

  
  % set the 'tag', which was stored above
  set(h_axes,'tag',tag_axes);
% END sor.mgol.m
