function temp_vert(action)
%
% 
% 
% Author:  Christian Sommer, Heinrich Sormann, Winfried Kernbichler
% Version: 1.0 
% Date:    January, 2002
% Status:  Test with "Test with 'Testimonial' - runs very well
%          Test with "Any boundary cond." - runs very well 

%          
%
% Test of all gui_routines

% ==========================================================================
% ==========================================================================
% one should keep this at the beginning of the file
% just change func_name
func_name = 'temp_vert';                    % function name - same as declaration
% ==========================================================================
handle_name = [func_name,'_HANDLE'];  % name of global variable
eval(['global ',handle_name]);        % set it global
if nargin == 0, action = 'initgraph'; end  % set to 'initgraph', if there is no input
if ~strcmp(action,'initgraph'), 
  eval(['HANDLE=',handle_name,';']);  % copy global to local
else
  % one can change this strings
  logo_switch = 1;                  % logo: yes (1), no (0)
  fig_title   = 'Loesung der 2-dim. Laplacegleichung mittels Differenzenverfahren';
  logo_title  = 'Temperaturverteilung eines 2-dimensionalen ebenen Gebietes';
  logo_name   = 'Christian Sommer, Heinrich Sormann, Winfried Kernbichler';
  logo_lv     = 'Multimediale Lehre';
  logo_type   = 'logo_1';           % only this is defined at the moment
  min_punkte  = 12;                 % min. Anzahl der Punkte im Inneren des Gebietes
  max_punkte  = 1546;               % max. Anzahl der Punkte im Inneren des Gebietes
  sta_punkte  = 325;                % standard points
  min_tol     = ceil(log10(eps));   % minimum toleranz fuer die Iterationsgenauigkeit (10er Potenz)
  max_tol     = -1;                 % maximum toleranz fuer die Iterationsgenauigkeit (10er Potenz)
  sta_tol     = -5;                 % standard toleranz
  min_iter    = 100;                % minimum number of iterations
  max_iter    = 2000;               % maximum number of iterations
  sta_iter    = 300;                % standard number of iterations
  min_delay   = 1;                  % min. Verzoegerung beim Iterationsverlauf
  max_delay   = 20;                 % max. Verzoegerung beim Iterationsverlauf
  sta_delay   = 5;                  % standard Verzoegerung beim Iterationsverlauf
  
  % some colors
  ax_color = [0.9,0.9,0.9];         % default axes color
  bo_color = [0.6,0.6,0.6];         % default border color
  % do not change
  HANDLE = [];                      % empty at the beginning
end
%keyboard
% ==========================================================================
% ==========================================================================
% Here every aspect of the graphics part should be handled
% This contains the definition and the callback routines
switch lower(action)
  % ========================================================================
  % initialization of program
  case 'initgraph'    
    % ----------------------------------------------------------------------
    % preprocessing for initgraph (keep this lines) 
    eval( [func_name,' ''initgraph_pre'''] );            % graphcon 'initgraph_pre' = graphcon(initgraph_pre)
                                                         % d.h. ruft sich selbst auf!
    % ----------------------------------------------------------------------
 
    % ---------------------------------------------------------------------- 
    % definition and creation of graphics objects
    % ----------------------------------------------------------------------
    % ======================================================================
    % ======================================================================
    % definition of main figure
    % ----------------------------------------------------------------------  
    F.figure = struct( ...
	'frame',    { [0.0, 0.0, 1.0, 1.0] }, ...
	'geometry', { [1] }, ...
	'closerequestfcn', { 'close_request_main' }, ...
	'name',     { fig_title }, ...
	'renderer', { 'opengl' }, ...
	'tag',      { 'main' } ...
	);
   
    % --- should be kept ---------------------------------------------------  
    [HANDLE,fig_han] = gui_create(gui_define(F),HANDLE); % creation
    clear F;                                      % not needed any more
    % add function name to tag and closerequestfcn
    % important for finding program related figures and to find function
    gui_add_name(fig_han,func_name,'_','b','tag');
    gui_add_name(fig_han,func_name,' ','b','closerequestfcn');
    % sets necessary userdata for figures
    gui_set_userdata(fig_han, ...
	'function',func_name, ...
	'end','exit');
    figmain_han = fig_han;
    % figure color
    fig_color = get( ...
	gui_handle_query(HANDLE.figure,'tag','*main*'),'color');
    % ----------------------------------------------------------------------
    
    % ----------------------------------------------------------------------  
    % create meta frames
    % ----------------------------------------------------------------------  
    if logo_switch
      logo_y_pos  = 0.9; % y division between logo and rest
    else
      logo_y_pos  = 1.0;
    end
    meta_frame_logo   = [0, logo_y_pos, 1, 1-logo_y_pos]; % logo
    meta_frame_layer1 = [0, 0,          1, logo_y_pos  ]; % layer 1   
    % ----------------------------------------------------------------------  
    %keyboard
    % ----------------------------------------------------------------------  
    % create logo
    % ----------------------------------------------------------------------
    if logo_switch
      % --------------------------------------------------------------------  
      logo_string = {logo_title,logo_name,logo_lv};
      logo_parent = figmain_han;
      % here one could use HANDLE instead of HANDLE_LOGO, then one could 
      % refere to all contents within the rest of the program.
      % When using HANDLE_LOGO this graphics part stays seperate. 
      HANDLE_LOGO = [];
      HANDLE_LOGO = gui_create_logo(HANDLE_LOGO, logo_string, ...
	  logo_parent, meta_frame_logo, logo_type);
    end
    % ----------------------------------------------------------------------  
    % ----------------------------------------------------------------------  

    % ---------------------------------------------------------------------- 
    % create main frames at 6 positions
    %  four joined parts with division lines given at 
    %  x: x_div_pos y: y_div_pos
    % ----------------------------------------------------------------------  
    mf = meta_frame_layer1;    % choose meta frame
    x_div_pos = 0.85 * mf(3);  % division line in x direction
    y_div_pos = 0.17 * mf(4);  % division line in y direction
    % frames for lower-left, lower-middle, lower-right, upper-left, upper-right
    ll_frame = [ mf(1),           mf(2),             ...
	  2*x_div_pos/3,       y_div_pos ];
    lm_frame = [ mf(1)+2*x_div_pos/3, mf(2),         ...
	  x_div_pos/3,       y_div_pos ];  
    lr_frame = [ x_div_pos,       mf(2) ,            ...
	  mf(3)-x_div_pos, y_div_pos ];
    ul_frame = [ mf(1),           y_div_pos,         ...
	  x_div_pos,       mf(4)-y_div_pos ];
    urm_frame = [ x_div_pos,           y_div_pos,         ...
	  mf(3)-x_div_pos,       3*(mf(4)-y_div_pos)/4 ];
    ur_frame = [ x_div_pos,       y_div_pos + 3*(mf(4)-y_div_pos)/4,         ...
	  mf(3)-x_div_pos, (mf(4)-y_div_pos)/4 ];
	   
    % ----------------------------------------------------------------------  
    % definition of some basis axes system for the background of all five
    % parts defined in the meta frame.
    Fbasis.axes = struct( ...
	'geometry', { [1] }, ...
	'xborder',  { [0.0, 0.0] }, ...
	'yborder',  { [0.0, 0.0] }, ...
	'xgap',     { [0.0] }, ...
	'ygap',     { [0.0] }, ...	
	'parent',   { [1] }, ...
	'visible',  { 'on' }, ...
	'box',      { 'on' }, ...
	'xtick',    { [] }, ...
	'ytick',    { [] }, ...
	'color',    { ax_color }, ...
	'xcolor',   { bo_color }, ...
	'ycolor',   { bo_color } ...	
	);
    % ======================================================================
    % ======================================================================
    % lower left position (containing sliders)
    % ---------------------------------------------------------------------- 
    % basic axis for background
    % fuegt d. Struktur 'Fbasis.axes' die Eigenschaft 'frame' mit dem
    % Wert 'll_frame' hinzu!
    Fbasis.axes = setfield(Fbasis.axes,'frame',ll_frame ); % set 'structure' 
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'lower_left',' ','b','tag');            
    
    % definitions of slider values
    geom = [ 1, 1; 1, 1];
    % typical values
    visible = { 'on', 'on'; 'on', 'on'  };
    minval  = { min_punkte, min_iter; min_tol,  min_delay  }; % minimum
    maxval  = { max_punkte, max_iter; max_tol,  max_delay  }; % maximum
    svalue  = { sta_punkte, sta_iter; sta_tol,  sta_delay  }; % value for slider
    evalue = svalue;                            % value for edit (string)
    for k = 1:length(svalue(:)), evalue{k} = num2str(svalue{k}); end

    cab = 'set_value';  % 'callback' String
    str = { ...
	'Number of points','Max. iteration'; ...
        'rel. Tolerance            in 10^', 'Delay iteration display' ...
	};
    tag = { 'number_points','iter_max'; 'tol','delay' };
    % create variables from string
    var = transpose(flipud(lower(tag))); % variables
    % here transpose and flipud is necessary to allow later use with
    % gui_add_userdata 
    % graphics objects are counted from lower left corner along the 
    % second dimension, arrays and cells from upper left corner along
    % the first dimension.
    % The command lower is used to make sure variable names are lower
    % case.

    % callback action to be performed
    cb_ac = {'setup_punkte', 'setup_iter', 'setup_tol', 'setup_delay'}; 
    cbaction = { cb_ac{1}, cb_ac{2}; cb_ac{3}, cb_ac{4} };
    cbaction = transpose(flipud(lower(cbaction)));
    % what should be changed in the slider
    cb_ch1 = { 'value','round(##)' };
    cb_ch2 = { 'value','intervall_points(##,2)'};
    cbchange_sl = { cb_ch2, cb_ch1; cb_ch1, cb_ch1 }; 
    cbchange_sl = transpose(flipud(cbchange_sl));
    % what should be changed in the edit field
    cb_ch1 = { 'string','num2str((round(str2num(##))))' };
    cb_ch2 = { 'string','num2str(intervall_points(##,2))'};
    cbchange_ed = { cb_ch2, cb_ch1; cb_ch1, cb_ch1 };
    cbchange_ed = transpose(flipud(cbchange_ed));
    % what should be updated when slider changes, see also updatehandle
    update_sl = { { 'value','string','num2str(##)' } };
    update_sl = transpose(flipud(update_sl));
    % what should be updated when edit changes, see also updatehandle    
    update_ed = { { 'string','value','str2num(##)' } };
    update_ed = transpose(flipud(update_ed));
    % nur fuer das Testbsp. ist rechts unten 'edit-slider' deaktiviert
    enable = { 'on','on';'on','off' };
    
    % Uicontrol 'structur' fuer 'slider' in 'lower left frame'
    Fslider.uicontrol = struct( ...
	'frame',         { ll_frame }, ...
	'geometry',      { geom }, ...
	'xborder',       { [0.05, 0.05] }, ...
	'yborder',       { [0.1, 0.3] }, ...
	'xgap',          { [0.05] }, ...
	'ygap',          { [0.3] }, ...
	'xshift',        { [0.0] }, ...	
	'yshift',        { [0.0] }, ...	
	'xmodify',       { 'size' }, ...
	'parent',        { [1] }, ...
	'style',         { 'slider' }, ...
	'min',           { minval }, ...
	'max',           { maxval }, ...
	'value',         { svalue }, ...
	'visible',       { visible }, ...
	'enable',        { enable }, ...
	'interruptible', { 'off' }, ...
	'fontsize',      { 1 }, ...
	'string',        { str }, ...
	'callback',      { cab }, ...
	'tag',           { tag } ...
	);
    % Erzeugt 'slider' handle
    [HANDLE,slider_han] = gui_create(gui_define(Fslider),HANDLE); 
    %keyboard                                                        
    % sets variable name in userdata + action and update information
    gui_set_userdata(slider_han,'variable',var);     % speichert 'var' in 'userdata' von 'slider_han'
    gui_set_userdata(slider_han,'cbchange',cbchange_sl);
    gui_set_userdata(slider_han,'updateproperty',update_sl);
    gui_set_userdata(slider_han,'int_point',0);        % wird spaeter ein 2_dim Feld, das die Intervallanzahl
                                                       % und die dazugehoerigen Punkte enthalten  
   
    gui_add_name(slider_han,'slider',' ','e','tag');   % fuegt der Eigenschaft 'tag' hinten ' slider'
                                                       % hinzu. z.B 'delay slider'                               
   
    % add edit field shifted above (look for 'yshift')
    Fslider.uicontrol = setfield(Fslider.uicontrol,'xmodify',             'right');
    Fslider.uicontrol = setfield(Fslider.uicontrol,'xsize',                 0.10);
    Fslider.uicontrol = setfield(Fslider.uicontrol,'yshift',                0.2);
    Fslider.uicontrol = setfield(Fslider.uicontrol,'style',               'edit');
    Fslider.uicontrol = setfield(Fslider.uicontrol,'horizontalalignment', 'left');    
    Fslider.uicontrol = setfield(Fslider.uicontrol,'string',              evalue);    
    Fslider.uicontrol = setfield(Fslider.uicontrol,'fontsize',              0.60);
    Fslider.uicontrol = setfield(Fslider.uicontrol,'callback',      'edit_check');
    Fslider.uicontrol = setfield(Fslider.uicontrol,'backgroundcolor',ax_color);
    % Erzeugt 'edit' handle
    [HANDLE,edit_han] = gui_create(gui_define(Fslider),HANDLE);
    % sets variable name in userdata + action and update information
    gui_set_userdata(edit_han,'variable',var); 
    gui_set_userdata(edit_han,'cbchange',cbchange_ed);
    gui_set_userdata(edit_han,'updateproperty',update_ed);
    gui_set_userdata(edit_han,'int_point',0);          % wird spaeter die Intervallanzahl
                                                       % und die dazugehoerigen Punkte enthalten
    gui_set_userdata(edit_han,'callback',[func_name,' ',cab]);
    gui_add_name(edit_han,'slider_edit',' ','e','tag');    

    % add text shifted above 
    Fslider.uicontrol = setfield(Fslider.uicontrol,'xmodify',              'left');
    Fslider.uicontrol = setfield(Fslider.uicontrol,'xsize',                  0.30);
    Fslider.uicontrol = setfield(Fslider.uicontrol,'yshift',                  0.17);
    Fslider.uicontrol = setfield(Fslider.uicontrol,'style',                'text');
    Fslider.uicontrol = setfield(Fslider.uicontrol,'horizontalalignment',  'left');    
    Fslider.uicontrol = setfield(Fslider.uicontrol,'string',                  str);    
    Fslider.uicontrol = setfield(Fslider.uicontrol,'fontsize',                0.8);
    Fslider.uicontrol = setfield(Fslider.uicontrol,'callback',                 '');
    Fslider.uicontrol = setfield(Fslider.uicontrol,'backgroundcolor',    ax_color);   
    [HANDLE,text_han] = gui_create(gui_define(Fslider),HANDLE);
    gui_add_name(text_han,'slider_text',' ','e','tag');    

    % updatehandle for slider (handles of edit)
    edit_cell = mat2cell(edit_han,1,ones(size(edit_han)));
    gui_set_userdata(slider_han,'updatehandle',edit_cell); 
    % updatehandle for edit (handles of slider)
    slider_cell = mat2cell(slider_han,1,ones(size(slider_han)));
    gui_set_userdata(edit_han,'updatehandle',slider_cell); 
    % adds function name to callback, z.B. 'temp_vert set_value'
    % d.h. die function temp_vert(set_value) wird auf gerufen!  
    gui_add_name([slider_han,edit_han],func_name,' ','b','callback');
    % adds common name to tag
    gui_add_name([slider_han,edit_han,text_han],'lower_left',' ','b','tag');
    % clears structure 'Fslider'    
    clear Fslider
    
    % ======================================================================
    % ======================================================================
    % lower middle position
    % ----------------------------------------------------------------------
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',lm_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'lower_middle',' ','b','tag');
    
    geom    = [1 1; 1 1];
    str     = {'Display iter. OFF','dummy1'; 'dummy2','dummy3'};
    visible = {'on','off'; 'off','off'};
    cab     = {'display_iter','dummy1'; 'dummy2','dummy3'};
    tag     = cab;
     % Structure fuer 'togglebutton' (enthaelt alle 4 buttons, nur einer sichtbar!)
    Ftog.uicontrol = struct( ...
	'frame',    { lm_frame }, ...
	'geometry', { geom }, ...
	'xborder',      { [0.08, 0.08] }, ...
	'yborder',      { [0.02, 0.1] }, ...
	'xgap',         { [0.05] }, ...
	'ygap',         { [0.1] }, ...
	'parent',   { [1] }, ...
	'style',    { 'togglebutton' }, ...
        'visible',  { visible }, ...
	'enable',   { 'off' }, ...
	'value',    { [0] }, ...
	'fontsize', { 0.3 }, ...
	'string',   { str }, ...
	'callback', { cab }, ...
        'tag',      { tag } ...
	);
    %Erzeugt 'handle' zum  'togglebutton'
    [HANDLE,h_toggle] = gui_create(gui_define(Ftog),HANDLE); clear Ftog;
    gui_add_name(h_toggle,func_name,' ','b','callback');
    gui_add_name(h_toggle,'lower_middle',' ','b','tag');
    
    % --------------- Ende Initialisierung 'togglebutton' --------------------
    
    % --------- Beginn Initialisierung 'edit' Felder fuer Ausgabe  -----------   
    geom    = [ 2 2 3 3 ; 4 4 5 5 ; 6 6 7 7 ];  % erzeugt 6 edit felder (2 hor, 3 vert)
    visible = { 'off','off','off','off' ;...
		'off','off','off','off' ;...
		'on','on','off','off' };
    str     = { '','','',''; ...
		'','','',''; ...
		'Relaxationp.','Relaxationp.','',''};
    tag     = { 'dummy1','dummy1','dummy2','dummy2';...
		'dummy3','dummy3','dummy4','dummy4';...
		'relax_par','relax_par','dummy5','dummy5'};
    cab = lower(tag);
    % Uicontrol 'structur' fuer 'edit' in 'lower middle frame'
    Fedit.uicontrol = struct( ...
	'frame',         { lm_frame }, ...
	'geometry',      { geom }, ...
	'xborder',       { [0.08, 0.08] }, ...
	'yborder',       { [0.07, 0.1] }, ...
	'xgap',          { [0.05] }, ...
	'ygap',          { [0.14] }, ...
	'xshift',        { [0.0] }, ...	
	'yshift',        { [0.0] }, ...	
	'xmodify',       { 'size' }, ...
	'parent',        { [1] }, ...
	'style',         { 'edit' }, ...
	'visible',       { visible }, ...
	'horizontalalignment', 'left', ...
	'interruptible', { 'off' }, ...
	'fontsize',      { 0.6 }, ...
	'string',        { '' }, ...
	'callback',      { cab }, ...
	'tag',           { tag } ...
	);
    [HANDLE,h_edit_relax] = gui_create(gui_define(Fedit),HANDLE);
    gui_add_name(h_edit_relax,func_name,' ','b','callback');
    gui_add_name(h_edit_relax,'lower_middle',' ','b','tag');
    
    % Ueberschrift fuer 'edit' Felder
    Fedit.uicontrol = setfield(Fedit.uicontrol,'yshift',                 0.17);
    Fedit.uicontrol = setfield(Fedit.uicontrol,'style',                'text');
    Fedit.uicontrol = setfield(Fedit.uicontrol,'horizontalalignment',  'left');    
    Fedit.uicontrol = setfield(Fedit.uicontrol,'string',                  str);    
    Fedit.uicontrol = setfield(Fedit.uicontrol,'fontsize',                0.6);
    Fedit.uicontrol = setfield(Fedit.uicontrol,'callback',                 '');
    Fedit.uicontrol = setfield(Fedit.uicontrol,'tag',                     tag);
    Fedit.uicontrol = setfield(Fedit.uicontrol,'backgroundcolor',    ax_color);   
    [HANDLE,text_han] = gui_create(gui_define(Fedit),HANDLE); clear Fedit;
    gui_add_name(text_han,'edit_text',' ','e','tag');   
    
    % Ausgabe der Iterationsparamter auf 'frame' mittels 'text' 'uicontrol'
    geom    = [ 2 3 ; 2 3 ];  % erzeugt 2 edit felder nebeneinander
    visible = { 'off','on' ;'off','on'};
   
    %str2mat('Iter.num.:','Iter.error:','Relax.para.:','Iter.status:')
    Fframe.uicontrol = struct( ...
	'frame',         { lm_frame }, ...
	'geometry',      { geom }, ...
	'xborder',       { [0.08, 0.08] }, ...
	'yborder',       { [0.07, 0.1] }, ...
	'xgap',          { [0.05] }, ...
	'ygap',          { [0.1] }, ...
	'xshift',        { [0.0] }, ...	
	'yshift',        { [0.0] }, ...	
	'xmodify',       { 'size' }, ...
	'parent',        { [1] }, ...
	'style',         { 'frame' }, ...
	'visible',       { visible } ...
	);
    [HANDLE,h_frame] = gui_create(gui_define(Fframe),HANDLE); clear Fframe;
    
    % 'text' fuer die Iterationsparamterausgabe
    tag    = { '','output_par' ; '','output_par' };
    str_mat = str2mat('Iter.num.:','','Iter.error:','','Relax.para.:','','Convergence:');
    str     = { '',str_mat ; '',str_mat};
    Ftext.uicontrol = struct( ...
	'frame',         { lm_frame }, ...
	'geometry',      { geom }, ...
	'xborder',       { [0.08, 0.08] }, ...
	'yborder',       { [0.07, 0.1] }, ...
	'xgap',          { [0.05] }, ...
	'ygap',          { [0.1] }, ...
	'xshift',        { [0.0] }, ...	
	'yshift',        { [0.0] }, ...	
	'xmodify',       { 'size' }, ...
	'parent',        { [1] }, ...
	'style',         { 'text' }, ...
	'visible',       { visible }, ...
	'horizontalalignment', 'left', ...
	'interruptible', { 'off' }, ...
	'fontsize',      { 0.112 }, ...
	'string',        { str }, ...
	'tag',           { tag } ...
	);
    [HANDLE,h_text_out] = gui_create(gui_define(Ftext),HANDLE); clear Ftext;
    gui_add_name(h_text_out,func_name,' ','b','callback');
    gui_add_name(h_text_out,'lower_middle',' ','b','tag');
    gui_set_userdata(h_text_out,'str_mat',str_mat);
    
    % ======================================================================
    % ======================================================================  
    % lower right position
    % ----------------------------------------------------------------------  
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',lr_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'lower_right',' ','b','tag');            

    % ----------------------------------------------------------------------  
    % define uicontrol pushbutton
    geom = [1,1 ; 1,1];
    str = reshape({ 'Start','Help', 'Stop', 'Exit'},size(geom));  %'cell' string
    tag = lower(str);
    cab = lower(str);
    
    % Structure fuer 'pushbutton' (enthaelt alle 4 buttons)
    F.uicontrol = struct( ...
	'frame',    { lr_frame }, ...
	'geometry', { geom }, ...
	'parent',   { [1] }, ...
	'style',    { 'pushbutton' }, ...
	'visible',  { 'on' }, ...
	'fontsize', { 0.3 }, ...
	'string',   { str }, ...
	'callback', { cab }, ...
	'tag',      { tag } ...
	);
    % Erzeugt 'handle' zu den einzelnen 'pushbuttons'
    [HANDLE,newh] = gui_create(gui_define(F),HANDLE); clear F;
    gui_add_name(newh,func_name,' ','b','callback');
    gui_add_name(newh,'lower_right',' ','b','tag');            
    % settings for 'stop' handle
    h_stop = gui_handle_query(newh,'tag','*stop');
    gui_set_userdata(h_stop,'stop',0);
    set(h_stop,'enable','off');
    h_start = gui_handle_query(newh,'tag','*start');
    gui_set_userdata(h_start,'start',[0, 0]);
    
    % ======================================================================
    % ======================================================================
    % upper right middle position
    % ----------------------------------------------------------------------
    Fbasis.axes = setfield(Fbasis.axes,'frame',urm_frame ); % set 'structure' 
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'upper_right_middle',' ','b','tag');
    
    % 'text' Feld
    geom = [ 1 ; 1 ; 1 ; 1 ; 1 ; 1 ];
    
    visible = { 'on'; 'on' ; 'on' ; 'off' ; 'on' ; 'off' };
    tag = { '3Dplotmod'; '3Dcolor';'3Dshading';'dummy1';'Interpolation';'dummy2'};
    cab = { 'plotmodus_3d'; 'color_3d'; 'shading_3d';'dummy1';'interpolation'; 'dummy2'};
    value = { 1 ; 1; 1; 1 ; 1 ; 1};
    str = { '3D plotstyle';'3D color';'3D shading';'';'Interpolation';'' };
    Ftext.uicontrol = struct( ...
	'frame',                 { urm_frame }, ...
	'geometry',             { geom }, ...
	'yborder',              { [0.25,0.1] }, ...
	'ygap',                 { [0.07] }, ...
	'yshift',               { [0.033]}, ...
	'horizontalalignment',  {'left'}, ...
	'parent',               { [1] }, ...
	'style',                { 'text' }, ...
	'visible',              { visible }, ...
	'fontsize',             { 0.53 }, ...
	'value',                { value },...
	'string',               { str }, ...
	'callback',             { cab }, ...
	'tag',                  { '' }, ...
	'backgroundcolor',      {ax_color} ...
	);
    [HANDLE,text_han] = gui_create(gui_define(Ftext),HANDLE); clear Ftext;
    % Preferenzen fuer 'popup'
    str = { ' surf| surfl| surfc| mesh| meshc| meshz| waterfall| contour| contour3| contourf'; ...
	    ' jet| hsv| cool| hot| gray| pink| copper| spring| summer| autumn| winter| prism| bone'; ...
            ' faceted| interp| flat '; ...
	    ' dummy3'; ...
	    ' linear| pchip'; ...
	    ' dummy4' };
    enable = { 'off'; 'off' ; 'off' ; 'off' ; 'off' ; 'off' };
    % 3D-Plot Modi
    
    cmdList1 = str2mat(' h_p = surf(X,Y,##); h_cb = colorbar;',      ...
		       ' h_p = surfl(X,Y,##); h_cb = [];',           ...
		       ' h_p = surfc(X,Y,##); h_cb = colorbar;',     ...
		       ' h_p = mesh(X,Y,##); h_cb = colorbar;',      ...
                       ' h_p = meshc(X,Y,##); h_cb = colorbar;',     ...
		       ' h_p = meshz(X,Y,##); h_cb = colorbar;',     ...
		       ' h_p = waterfall(X,Y,##); h_cb = colorbar;', ...
                       ' [c, h_p] = contour(X,Y,##,10); h_cb = colorbar;',  ...
		       ' [c, h_p] = contour3(X,Y,##,10); h_cb = colorbar;', ...
		       ' [c, h_p] = contourf(X,Y,##,10); h_cb = colorbar;');      
			
	%' [c, h_p] = contour(X,Y,##,10); clabel(c,h_p,''color'',''k''); h_cb = colorbar;',  ...
	%	       ' [c, h_p] = contour3(X,Y,##,10); clabel(c,h_p,''color'',''k''); h_cb = colorbar;', ...
	%	       ' [c, h_p] = contourf(X,Y,##,10); clabel(c,h_p,''color'',''k''); h_cb = colorbar;'); 	       
    % 3D-Plot Color
    cmdList2 = char(' colormap(jet)',' colormap(hsv)',' colormap(cool)',' colormap(hot)', ...
               ' colormap(gray)',' colormap(pink)',' colormap(copper)',' colormap(spring)', ...
               ' colormap(summer)',' colormap(autumn)',' colormap(winter)', ' colormap(prism)',' colormap(bone)');
 
    cmdList3 = char('shading faceted','shading interp','shading flat');
    
    % structur fuer 'popup'
    Fpop.uicontrol = struct( ...
	'frame',                { urm_frame }, ...
	'geometry',             { geom }, ...
	'yborder',              { [0.25,0.1] }, ...
	'ygap',                 { [0.065] }, ...
	'parent',               { [1] }, ...
	'style',                { 'popup' }, ...
	'visible',              { visible }, ...
	'enable',               { enable }, ...
	'fontsize',             { 0.46 }, ...
	'value',                { value },...
	'string',               { str }, ...
	'callback',             { cab }, ...
	'tag',                  { tag } ...
	);
    [HANDLE,h_plotmod] = gui_create(gui_define(Fpop),HANDLE);
    gui_add_name(h_plotmod,func_name,' ','b','callback');
    gui_add_name(h_plotmod,'upper_right_middle',' ','b','tag');
    gui_set_userdata(h_plotmod,'plotstyle_3d',cmdList1);
    gui_set_userdata(h_plotmod,'color_3d',cmdList2);
    gui_set_userdata(h_plotmod,'shading',cmdList3); 
    
    % 'pushbutton' 
    str = { ' dummy1'; ...
	    ' dummy2'; ...
	    ' dummy3'; ...
	    ' Set boundary'; ...
	    ' dummy4'; ...
	    ' Clear deviation'};
    
    visible = { 'off'; 'off' ; 'off' ; 'on' ; 'off' ; 'on'  };
    enable = { 'off'; 'off' ; 'off' ; 'off' ; 'off' ; 'off' };
    tag = { ' dummy1'; ...
	    ' dummy2'; ...
	    ' dummy3'; ...
	    ' Set_boundary'; ...
	    ' dummy4'; ...
	    ' Clear_deviation'};
    
    cab = lower(tag);
    % structur fuer 'pushbutton'
    Fpush.uicontrol = struct( ...
	'frame',    { urm_frame }, ...
	'geometry', { geom }, ...
	'yborder',  { [0.23,0.1] }, ...
	'ygap',     { [0.05] }, ...
	'parent',   { [1] }, ...
	'style',    { 'pushbutton' }, ...
	'visible',  { visible }, ...
	'enable',   { enable }, ...
	'fontsize', { 0.35 }, ...
	'string',   { str }, ...
	'callback', { cab }, ...
	'tag',      { tag } ...
	);
    [HANDLE,h_push] = gui_create(gui_define(Fpush),HANDLE); clear Fpush;
    gui_add_name(h_push,func_name,' ','b','callback');
    gui_add_name(h_push,'upper_right_middle',' ','b','tag'); 
   
    
   % keyboard
    % ======================================================================
    % ======================================================================
    % upper right position
    % ----------------------------------------------------------------------  
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',ur_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);
    gui_add_name(newh,'upper_right',' ','b','tag');            

    
    geom = [1;1];
    str = { 'dummy';'Choice'}; 
    visible = { 'off'; 'on'};
    tag = { 'dummy';'berech_modus'};
    cab = { 'dummy'; 'berechnungsmodus' };
    % Ueberschrift fuer 'pop' Menu
     Ftext.uicontrol = struct( ...
	'frame',                 { ur_frame }, ...
	'geometry',             { geom }, ...
	'yborder',              { [0.25,0.05] }, ...
	'ygap',                 { [0.02] }, ...
	'yshift',               { [0.14]}, ...
	'horizontalalignment',  {'left'}, ...
	'parent',               { [1] }, ...
	'style',                { 'text' }, ...
	'visible',              { visible }, ...
	'fontsize',             { 0.34 }, ...
	'string',               { str }, ...
	'callback',             { cab }, ...
	'tag',                  { '' }, ...
	'backgroundcolor',      {ax_color} ...
	);
    [HANDLE,text_han] = gui_create(gui_define(Ftext),HANDLE); clear Ftext
    gui_add_name(text_han,'pop_text',' ','e','tag');
    
    % 'popup' Menue fuer Auswahl zw. Testbeispiel und fuer bel. Randbedingungen
    str = { 'dummy';' Testimonial| Any boundary cond.'};
    visible = { 'off'; 'on'};
    
    Fpop.uicontrol = struct( ...
	'frame',    { ur_frame }, ...
	'geometry', { geom }, ...
	'yborder',  { [0.25,0.05] }, ...
	'ygap',     { [0.02] }, ...
	'parent',   { [1] }, ...
	'style',    { 'popup' }, ...
	'visible',  { visible }, ...
	'fontsize', { 0.22 }, ...
	'value',    { { 1 ; 1 } },...
	'string',   { str }, ...
	'callback', { cab }, ...
	'tag',      { tag } ...
	);
    [HANDLE,h_wahl] = gui_create(gui_define(Fpop),HANDLE);
    gui_add_name(h_wahl,func_name,' ','b','callback');
    gui_add_name(h_wahl,'upper_right',' ','b','tag');
  
    
    % ======================================================================
    % ======================================================================
    % upper left position
    % ----------------------------------------------------------------------
    % basic axis for background
    Fbasis.axes = setfield(Fbasis.axes,'frame',ul_frame );
    Fbasis.axes = setfield(Fbasis.axes,'tag','base_axes');
    [HANDLE,newh] = gui_create(gui_define(Fbasis),HANDLE);    
    gui_add_name(newh,'upper_left',' ','b','tag');            

    % ----------------------------------------------------------------------  
    % add first axes for results of 'Testimonial'
    geom = [ 4,4,3,3 ; 4,4,3,3 ; 2,2,1,1 ];
    tag  = { ...
	'temp_iter1','temp_iter1','temp_exakt','temp_exakt';    ...
        'temp_iter1','temp_iter1','temp_exakt','temp_exakt';    ...
        'temp_diff','temp_diff','temp_mittel_diff','temp_gebiet1'  ...
	    };
    box = { 'on','on','on','on'; ...
	    'on','on','on','on'; ...
	    'on','on','on','off'};
    % 'axes' structure for all axis
    F.axes = struct( ...
	'frame',    { ul_frame }, ...
	'geometry', { geom }, ...
	'parent',   { [1] }, ...
	'visible',  { 'on' }, ...
	'box',      { box }, ...
	'tag',      { tag } ...
	);
    % erzeugt handle zur jeweiligen 'axes'
    [HANDLE,axes_h_test] = gui_create(gui_define(F),HANDLE);
    gui_add_name(axes_h_test,'result','_','b','tag');
    gui_add_name(axes_h_test,'upper_left',' ','b','tag');

    % add lines to axes (temp_gebiet1)
    axes_h = HANDLE.axes;
    lax_h = gui_handle_query(axes_h,'tag','*temp_gebiet1');
    tag         = { 'region1', 'delim1'};
    col         = { 'b', 'r' };
    linestyle   = { '-', 'none' };
    linewidth   = { 1, 1 };
    markerstyle = { 'none',  'o' };
    markersize  = { 4, 4 };
    GUI.line = struct( 'parent', { lax_h }, ...
	'xdata',        { [] }, ...
	'ydata',        { [] }, ...
	'linewidth',    linewidth, ...
	'linestyle',    linestyle, ...
	'marker',       markerstyle, ...
	'markersize',   markersize, ...
	'erasemode',    'none', ...
	'color',        col, ...
	'tag',          tag ...
	);
    [HANDLE,line_area1] = gui_create(GUI,HANDLE); clear GUI
    
    % add lines to axes (temp_gebiet1)
    axes_h = HANDLE.axes;
    lax_h = gui_handle_query(axes_h,'tag','*temp_mittel_diff');
    tag         = { 'tempmax', 'tempmittel'};
    col         = { 'r', 'b' };
    linestyle   = { 'none', 'none' };
    linewidth   = { 1, 1 };
    markerstyle = { '*',  'o' };
    markersize  = { 4, 4 };
    GUI.line = struct( 'parent', { lax_h }, ...
	'xdata',        { [] }, ...
	'ydata',        { [] }, ...
	'linewidth',    linewidth, ...
	'linestyle',    linestyle, ...
	'marker',       markerstyle, ...
	'markersize',   markersize, ...
	'erasemode',    'none', ...
	'color',        col, ...
	'tag',          tag ...
	);
    [HANDLE,line_area1] = gui_create(GUI,HANDLE); clear GUI
    
    % ------------------------------------------------------------------------
    % add second axes for results of 'any boundary conditions'
    geom = [ 4,4,3,3 ; 4,4,3,3 ; 2,2,2,1 ];
    tag  = { ...
	'temp_iter2','temp_iter2','temp_verlauf','temp_verlauf';    ...
        'temp_iter2','temp_iter2','temp_verlauf','temp_verlauf';    ...
        'temp_bound_cond','temp_bound_cond','temp_bound_cond', 'temp_gebiet2'};
    % setzt gewisse Eintraege der vorigen 'structure' auf andere Werte 
    F.axes = setfield(F.axes,'geometry',     geom);
    F.axes = setfield(F.axes,'visible',     'off');
    F.axes = setfield(F.axes,'tag',     tag);
    [HANDLE,axes_h_bound] = gui_create(gui_define(F),HANDLE); clear F;
    gui_add_name(axes_h_bound,'result_bound','_','b','tag');
    gui_add_name(axes_h_bound,'upper_left',' ','b','tag');
    
    % add lines to axes (temp_gebiet2)
    axes_h = HANDLE.axes;
    lax_h = gui_handle_query(axes_h,'tag','*temp_gebiet2');
    tag         = { 'region2', 'delim2'};
    col         = { 'r', 'b' };
    linestyle   = { '-', 'none' };
    linewidth   = { 1, 1 };
    markerstyle = { 'none',  'o' };
    markersize  = { 4, 4 };
    GUI.line = struct( 'parent', { lax_h }, ...
	'xdata',        { [] }, ...
	'ydata',        { [] }, ...
	'linewidth',    linewidth, ...
	'linestyle',    linestyle, ...
	'marker',       markerstyle, ...
	'markersize',   markersize, ...
	'erasemode',    'none', ...
	'color',        col, ...
	'tag',          tag ...
	);
    [HANDLE,line_area2] = gui_create(GUI,HANDLE); clear GUI
    
    % add lines to axes (temp_bound_cond)
    axes_h = HANDLE.axes;
    lax_h = gui_handle_query(axes_h,'tag','*temp_bound_cond*');
   
    tag         = { 'tempbound', 'temppoints' };
    col         = { 'r', 'b' };
    linestyle   = { '-', 'none' };
    linewidth   = { 1, 1};
    markerstyle = { 'none', '*'};
    markersize  = { 4, 4};
    GUI.line = struct( 'parent', { lax_h }, ...
	'xdata',        { [] }, ...
	'ydata',        { [] }, ...
	'linewidth',    linewidth, ...
	'linestyle',    linestyle, ...
	'marker',       markerstyle, ...
	'markersize',   markersize, ...
	'erasemode',    'background', ...
        'Interruptible',{ 'on' }, ...
	'color',        col, ...
	'tag',          tag ...
	);
    [HANDLE,line_tempbound] = gui_create(GUI,HANDLE); clear GUI
  
    % ----------------------------------------------------------------------  
    % keep this here to store the local 'HANDLE' to the global 'handle_name'
    % ----------------------------------------------------------------------  
    eval( [handle_name,'=HANDLE;'] );
    eval( [func_name,' ''setup_line'''] );
    % keyboard
    % ----------------------------------------------------------------------  
    % postprocessing for initgraph (keep this lines)
    % ----------------------------------------------------------------------  
    eval( [func_name,' ''initgraph_post'''] );
    % ----------------------------------------------------------------------  
    
    % ----------------------------------------------------------------------  
    % set main figure to visible on (keep this lines)   
    % ----------------------------------------------------------------------
    %keyboard
    fig_han = eval([handle_name,'.figure']);   % get content of figure
    fig_han = gui_handle_query(fig_han,'tag',['*main']);
    set(fig_han,'visible','on');          % set figures to visible
    % ======================================================================
    %keyboard
  case 'initgraph_pre'               
    % preprocessing for initgraph (keep this lines)    
    % ======================================================================
    gui_default('set') % default values
    % close figures belonging to this program
    fig_han = get(0,'children');   
    fig_han = gui_handle_query(fig_han, ...
	'type','figure','tag',[func_name,'*']);
    delete(fig_han);
    % ======================================================================
  
  case 'initgraph_post'               
    % postprocessing for initgraph (keep this lines)   
    % ======================================================================
    gui_default('remove'); % reset defaults to MATLAB defaults
    % ======================================================================
  
  case 'exit'
  % finishing the program (keep this lines)
  % ========================================================================
    fig_han = eval([handle_name,'.figure']); % get all figures
    fig_han = fig_han(ishandle(fig_han));    % check if exist as handle
    delete(fig_han);                         % closes all figures
    clear('global',handle_name)              % deletes the global variable
    % ======================================================================
  
  case 'close_request_main'  
    % close request main (keep this lines)
    % ======================================================================
    func = gui_get_userdata(gcf,'function'); % function name
    exit = gui_get_userdata(gcf,'end');      % action for exit
    msg = { ...
	['Closing this figure exits program ',func,'.']; ...
	'Do you really want to exit?' ...
	};
    tit = 'Close Request Function';
    selection = questdlg(msg,tit,'Yes','No','Yes');
    switch selection,
      case 'Yes',
        close all
	%eval( [func,' ',exit] )
      case 'No'
	return
    end
    % ======================================================================
    
  case 'close_request_help'  
    % close request for help (keep this lines)
    % ======================================================================
    func = gui_get_userdata(gcf,'function');
    exit = gui_get_userdata(gcf,'end');
    msg = { ...
	'Closing this figure is not possible.'; ...
	'Do you want to make it invisible?' ...
	};
    tit = 'Close Request Function';
    selection = questdlg(msg,tit,'Yes','No','Yes');
    switch selection,
      case 'Yes',
	eval( [func,' ',exit] )
      case 'No'
	return
    end    
    % ======================================================================
        
  case 'help'
    % calling help
    % ======================================================================
    frame = [0.1, 0.1, 0.8, 0.5];
    [HANDLE,new] = gui_help(HANDLE,frame,func_name);
    if new, eval([handle_name,'=HANDLE;']); end % export to global
    % ======================================================================
  
  case 'edit_check'
    % checks string from edit field
    % ======================================================================
    str    = get(gcbo,'string');
    oldval = get(gcbo,'value');
    minval = get(gcbo,'min');
    maxval = get(gcbo,'max');
    val = str2num(str);
   % keyboard
    % handle all error cases
    if ~isempty(val)
      if val<minval
	msg = { 'Value to small!','Value set to minimum.' };
	e_han = msgbox(msg,'Edit Box','error','modal');
	set(gcbo,'string',num2str(minval));
      elseif val>maxval
	msg = { 'Value to large!','Value set to maximum.' };
	e_han = msgbox(msg,'Edit Box','error','modal');
	%e_han = errordlg(msg,'Edit Box','on');
	set(gcbo,'string',num2str(maxval));
      end
    else
      msg = { 'Wrong value!','Value set to old value.' };
      e_han = msgbox(msg,'Edit Box','error','modal');
      %e_han = errordlg(msg,'Edit Box','on');
      if isfield(get(gcbo,'userdata'),'updatehandle')
	updatehandle   = gui_get_userdata(gcbo,'updatehandle');      
	updateproperty = gui_get_userdata(gcbo,'updateproperty');
	oldval = get(updatehandle,updateproperty{2});
      end
      set(gcbo,'string',num2str(oldval));
    end
    
    % do the real callback
    if isfield(get(gcbo,'userdata'),'callback')
      eval( gui_get_userdata(gcbo,'callback') );
    end
    % ======================================================================
    
    
  case 'set_value'
    % get values from caller 
    % ======================================================================
    e_str  = gui_get_userdata(gcbo,'variable');
    % cbaction = gui_get_userdata(gcbo,'cbaction');
    figure_han = get(gcbo,'parent');
    func_name = gui_get_userdata(figure_han,'function');
    
    % make sure that only integer will set on 'edit' and 'slider'
    if isfield(get(gcbo,'userdata'),'cbchange')
      cbchange = gui_get_userdata(gcbo,'cbchange');
      tag_str = get(gcbo,'tag');
      prop = cbchange{1};
      chfunc = cbchange{2};
    % keyboard
      % fuer alle anderen 'tag_str' ist die erste Option erfuellt
      if isempty(findstr(tag_str,'number_points'))
	e_str = [ 'get(gcbo,''',prop,''')' ];
	e_str = strrep(chfunc,'##',e_str);
	e_str = [ 'set(gcbo,''',prop,''',',e_str,');' ];
	eval( e_str );
      else   % gilt nur fuer 'number of points'
	intervall_points = gui_get_userdata(gcbo,'int_point');
	if (length(intervall_points) == 1)   
	  intervall_points = temp_int_point;     % 2-dim. Feld aus
                                                 % function 'temp_int_point'
	  % wird fuer alle weiteren Verwendungen des 'slider' bzw. des
          % 'edit' Feldes gespeichert!
	  gui_set_userdata(gcbo,'int_point',intervall_points); 
	end
	
        e_str = [ 'get(gcbo,''',prop,''')' ];
	punkt_anz = eval(e_str);
	if isstr(punkt_anz)  % wenn Wert von 'edit' Feld
	  punkt_anz = str2num(punkt_anz);
	end
	% Index des naechst groesseren Wertes
	index_gr = min(find(intervall_points(:,2) >= punkt_anz));  % naechst groesser
	index_kl = max(find(intervall_points(:,2) <= punkt_anz));  % naechst kleiner
        diff_gr = intervall_points(index_gr,2) - punkt_anz;
	diff_kl = punkt_anz - intervall_points(index_kl,2);
	%keyboard
	if diff_gr <= diff_kl
	  e_str = strrep(chfunc,'##',num2str(index_gr));
	  e_str = [ 'set(gcbo,''',prop,''',',e_str,');' ];
	  eval( e_str );
	else
	  e_str = strrep(chfunc,'##',num2str(index_kl));
	  e_str = [ 'set(gcbo,''',prop,''',',e_str,');' ];
	  eval( e_str );
	end
      end
    end
   
    % do the update of the other handle (e.g. 'edit' was changed ->
    % 'slider' will be changed to the same value!
    if isfield(get(gcbo,'userdata'),'updatehandle')
      updatehandle   = gui_get_userdata(gcbo,'updatehandle');      
      updateproperty = gui_get_userdata(gcbo,'updateproperty');      
      if ~isempty(updatehandle)
	from_prop = updateproperty{1};
	to_prop   = updateproperty{2};
	chfunc    = updateproperty{3};
	e_str = [ 'get(gcbo,''',from_prop,''')' ];
	e_str = strrep(chfunc,'##',e_str);
	e_str = [ 'set(updatehandle,''',to_prop,''',',e_str,');' ];
	eval( e_str );
      end
    end
   
    % ======================================================================

  case 'start'
    % start Iteration
    % ======================================================================
    uicontrol_han = HANDLE.uicontrol;
    axes_han = HANDLE.axes;
    line_han = HANDLE.line;
    % aktiviert die 3D Plot Einstellungen
    h_pop_plotmode = gui_handle_query(uicontrol_han,'tag','*3Dplotmod');
    h_pop_col = gui_handle_query(uicontrol_han,'tag','*3Dcolor');
    h_pop_shad = gui_handle_query(uicontrol_han,'tag','*3Dshading');
    set([h_pop_plotmode h_pop_col h_pop_shad],'enable','on');
    
    % aktiviert den 'pushbutton' 'Clear Deviation'
    h_push_clear = gui_handle_query(uicontrol_han,'tag','*Clear_deviation');
    set(h_push_clear,'enable','on');
    
    % get variables from slider values
    data_handle = gui_handle_query(uicontrol_han,'tag','*slider');
    
    % set all variables ('number_points','iter_max', 'tol','delay')
    variables = gui_get_userdata(data_handle,'variable');
    values    = get(data_handle,'value');
    
    lv = length(values);
    % Zuweisung der eingelesenen Werte zu obigen Variablen!
    if lv==1
      eval([variables,'=values;']);
    else
      for k = 1:lv
	value = values{k};
	var   = variables{k};
	eval([var,'=value;']);
      end
    end
    tol=10^tol;     % da nur die Potenz im 'slider' und 'edit'-Feld
                    % angebenen ist!
    R = 4;          % Radius des Halbkreises	
    
    % --------------------------------------------------------------------
    % find handle of stop button and of buttons to be disabled
    stop_han = gui_handle_query(uicontrol_han,'tag','*stop');    
    disable_han = uicontrol_han(uicontrol_han~=stop_han);
    enable_status = {get(disable_han,'enable')};
    gui_set_userdata(gcbo,'enable_status',enable_status);        
    % disable buttons, popups and sliders, enable stop button
    set(disable_han,'enable','off');
    set(stop_han,'enable','on');
    % ---------------------------------------------------------------------
    
    h_pop_choice = gui_handle_query(uicontrol_han,'tag','*berech_modus');
    val_choice = get(h_pop_choice,'value');
    h_sli_points = gui_handle_query(uicontrol_han,'tag','*number_points slider');
    % enthaelt die Intervalle mit den zugehoerigen Punkten im inneren des Gebietes!
    intervall_points = gui_get_userdata(h_sli_points,'int_point');  
    
    % Berechnung der Koeffizientenmatrix und des Inhomogenitaetsvektors
    % des linearen Gleichungssytems der inneren Punkte
    if val_choice == 1
      if intervall_points == 0
        [koeff_mat,inhom_vec,X,Y,G,index_in] = koeffmat_inhom(number_points,val_choice);
      else
      [koeff_mat,inhom_vec,X,Y,G,index_in] = koeffmat_inhom(number_points,intervall_points,val_choice);
      end
    elseif val_choice == 2
      h_pop_interp = gui_handle_query(uicontrol_han,'tag','*Interpolation');
      val_interp = get(h_pop_choice,'value');
      h_axes_bound = gui_handle_query(axes_han,'tag','*bound_cond*');
      h_line_bound = gui_handle_query(line_han,'tag','*tempbound');
      l_bound = get(h_line_bound,'xdata') - 1;
      l_bound(end+1) = l_bound(end)+R/2;
      temp_bound = get(h_line_bound,'ydata');
      temp_bound(end+1) = temp_bound(1);
      if intervall_points == 0
        [koeff_mat,inhom_vec,X,Y,G,index_in] = koeffmat_inhom(number_points,val_choice, ...
						            val_interp,l_bound,temp_bound);
      else
	[koeff_mat,inhom_vec,X,Y,G,index_in] = koeffmat_inhom(number_points,intervall_points,val_choice, ...
						            val_interp,l_bound,temp_bound);
      end  
    end
    
     %keyboard
    % Bestimmung des Ralaxationsparameters (aus M-Skript: relaxpar.m)
    h_edit_rel = gui_handle_query(uicontrol_han,'tag','*relax_par');
    w_str = get(h_edit_rel,'string');
    if isempty(w_str)
      relaxpar;
    else
      w = str2num(w_str);
    end
    
      
    T_start = ones(number_points,1)*20;    % Startvektor fuer die
                                    % Temperaturverteilung (20 Grad Celsius)
    % Beginn der Iteration mittels sor.m			    
    if val_choice == 1 
      [T_iter_vec, error, iter, flag]  = sor(koeff_mat, T_start, inhom_vec, w, iter_max, tol);
    elseif val_choice == 2   % fuer bel. Randbedingungen
      h_tog = gui_handle_query(uicontrol_han,'tag','*display_iter*');
      val_disp = get(h_tog,'value');  % val_disp = 1 ... Iterationsverlauf wird gezeigt
				      % val_disp = 0 ... Iterationsverlauf wird nicht gezeigt
      if val_disp == 0     
	[T_iter_vec, error, iter, flag]  = sor(koeff_mat, T_start, inhom_vec, w, iter_max, tol);
      else
	h_axes_disp = gui_handle_query(axes_han,'tag','*temp_verlauf');
        [T_iter_vec, error, iter, flag]  = sor_disp(koeff_mat, T_start, inhom_vec, w, iter_max, tol, h_axes_disp, delay, ...
						    h_pop_plotmode, h_pop_col, h_pop_shad, X, Y, G, index_in, stop_han);
      end
    end
   % keyboard
    % Fuer die graphisch Darstellung muss der Loesungsvektor T_platte_vec wieder den einzelnen
    % Punkten auf der Platte (= Gebiet G) aufgepraegt werden.
    
    T_iter = reshape(G,length(G)^2,1);  % erzeugt einen Spaltenvektor, in dem die Spalten von
                                        % G hintereinander zusammengefuegt werden (nur Laenge
                                        % ist entscheidend!)
    % alle '0' im Gebiet werden 'NaN' gesetzt(uebersichtlichere Darstellung in den 'plots'
    Gnan=G;
    Gnan(find(G==0)) = NaN; 
    T_iter(index_in) = T_iter_vec;
    T_iter = reshape(T_iter,length(G),length(G)).*Gnan;
    %T_exakt_vec = temp_exakt(XG_vec,YG_vec);
   
   % drawnow
   % keyboard
   
   % keyboard
    % get data form 'popup' 'Plotstyle 3D'
    plot3d_nr = get(h_pop_plotmode,'value');
    plot3d_style_str = gui_get_userdata(h_pop_plotmode,'plotstyle_3d');
    % Erzeugung des 'eval strings' fuer die iter. Loesung
    ev_str1 = strrep(plot3d_style_str(plot3d_nr,:),'##','T_iter');
    
    % get data form 'popup' 'Color 3D'
    col_nr = get(h_pop_col,'value');
    col_str = gui_get_userdata(h_pop_col,'color_3d');
    ev_str_col = col_str(col_nr,:);
    % get data form 'popup' 'Shading 3D'
    shad_nr = get(h_pop_shad,'value');
    shad_str = gui_get_userdata(h_pop_shad,'shading');
    ev_str_shad = shad_str(shad_nr,:);
  
    % ---------------------------------------------------------------------------
    % Parameterausgabe im 'text' Feld 
    h_text_out = gui_handle_query(uicontrol_han,'tag','*output_par');
    str_mat = str2mat('Iter.num.:   ##','','Iter.error: ##','', ...
			'Relax.para.:  ##','','Convergence: ##');
    if flag == 0
      flag_str = 'YES';
    else
      flag_str = 'NO';
    end
      
    str_erg = str2mat(num2str(iter),'',num2str(error),'',num2str(w),'',flag_str);
    str     = { '',str_mat ; '',str_mat};
    anz = length(str_mat(:,1));
    l=1;
    for n = 1:anz
      if mod(n,2)
	str_new(n,:) = strrep(str_mat(n,:),'##',str_erg(n,:));
      else
	continue
      end
    end
     
    set(h_text_out,'string',str_new);
    % -----------------------------------------------------------------------------
    if val_choice == 1
      % Erzeugung des 'eval strings' fuer die exakte Loesung, sowie der Differenz
      ev_str2 = strrep(plot3d_style_str(plot3d_nr,:),'##','T_exakt');
      ev_str3 = strrep(plot3d_style_str(plot3d_nr,:),'##','T_diff');
      % Berechnung der exakten Loesung
      T_exakt = temp_exakt(X,Y).*Gnan;
      T_diff = T_iter - T_exakt;
      % Berechnung der maximalen und mittleren Abweichung
      index_in = find(G);
      XG_vec=X(index_in);              
      YG_vec=Y(index_in);
      T_exakt_vec = temp_exakt(XG_vec,YG_vec);
      T_diff_vec = abs(T_iter_vec - T_exakt_vec);
      T_diff_av = sum(T_diff_vec) /number_points;
      T_diff_max = max(T_diff_vec);
      
      % get handle form 'axes' with 'tag' '*temp_iter1' and '*temp_exakt' 
      h_axes_iter  = gui_handle_query(axes_han,'tag','*temp_iter1');
      h_axes_exakt = gui_handle_query(axes_han,'tag','*temp_exakt');
      h_axes_diff = gui_handle_query(axes_han,'tag','*temp_diff');
      h_axes_av = gui_handle_query(axes_han,'tag','*temp_mittel_diff');
      % zwischenspeichern der 'tag's
      tag_iter = get(h_axes_iter,'tag');
      tag_exakt = get(h_axes_exakt,'tag');
      tag_diff = get(h_axes_diff,'tag');
      
      axes(h_axes_iter);
      eval(ev_str1);          % ausfuehren des Graphikplots z.B. h_p = surf(X,Y,T_iter); h_cb = colorbar;
      eval(ev_str_col);       % ausfuehren 'colormap(...)'
      eval(ev_str_shad);      % ausfuehren 'shading ...'
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Temperature iterated','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{iter} / C','fontsize',12);
     % set(h_axes_iter,'fontsize',10);
     % set(h_cb,'fontsize',10);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p=reshape(h_p,1,[]);
      gui_set_userdata(h_axes_iter, 'handles_plot',[h_p h_cb]);
      %set(gca,'zlim',1.2*[min(min(T_iter)) max( max(T_iter))]);
      axes(h_axes_exakt);
      eval(ev_str2);
      eval(ev_str_col);
      eval(ev_str_shad);
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
     % set(h_axes_exakt,'fontsize',10);
      set(h_cb,'fontsize',10);
      title('Temperature analytical','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{exact} / C','fontsize',12);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p=reshape(h_p,1,[]);
      gui_set_userdata(h_axes_exakt,'handles_plot',[h_p h_cb]);
      axes(h_axes_diff);
      eval(ev_str3);
      eval(ev_str_col);
      eval(ev_str_shad);
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Difference of temperatures','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('\DeltaT / C','fontsize',12);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p=reshape(h_p,1,[]);
      gui_set_userdata(h_axes_diff, 'handles_plot',[h_p h_cb]);
      
      % speichern der 'plot' Daten fuer die Umschaltung der einzelnen Graphikoptionen!
      gui_set_userdata(h_axes_iter, 'x_sol',X);
      gui_set_userdata(h_axes_iter, 'y_sol',Y);
      gui_set_userdata(h_axes_iter, 'z_sol',T_iter);
      gui_set_userdata(h_axes_exakt,'z_sol',T_exakt);
      gui_set_userdata(h_axes_diff, 'z_sol',T_diff);
      % 'tags' muessen unverstaendlicherweise neu gesetzt werden!
      set(h_axes_iter, 'tag',tag_iter);
      set(h_axes_exakt,'tag',tag_exakt);
      set(h_axes_diff, 'tag',tag_diff);
      
      % Zeichnet 'line' fuer max. Abweichung und min Abweichung
      h_axes_av   = gui_handle_query(axes_han,'tag','*temp_mittel_diff');
      axes(h_axes_av);
      grid on
      title('Deviation');
      xlabel('# of independent iterations','fontsize',10);
      ylabel('\DeltaT_{av} \DeltaT_{max} / C','fontsize',10);
      set(h_axes_av,'xtick',1:10);
      lin_han = HANDLE.line;
      lin_han = gui_handle_query(lin_han,'parent',h_axes_av); 
      h_max  = gui_handle_query(lin_han,'tag','*tempmax');
      h_av = gui_handle_query(lin_han,'tag','*tempmittel');
      T_max_alt = get(h_max, 'ydata');
      T_av_alt = get(h_av, 'ydata');
      x_alt = get(h_max, 'xdata');
      set(h_max, 'ydata',[T_max_alt T_diff_max]);
      x = length(get(h_max,'ydata'));
      set(h_max, 'xdata', [x_alt x]);
      set(h_av,  'xdata',[x_alt x],       'ydata',[T_av_alt T_diff_av ]);
      if isempty(T_max_alt)
	set(gca,'xlim',1.125*[0 10],'ylim',[0 1]);
      else
        set(gca,'xlim',1.125*[0 10],'ylim',1.125*[0 max(T_max_alt)]);
      end
      
      % Setze userdata von 'start' auf 1
      h_start = gui_handle_query(uicontrol_han,'tag','*start');
      start_val = gui_get_userdata(h_start,'start');  % beim ersten mal ist start_val = [0, 0]
      if ~start_val(1)
        gui_set_userdata(h_start,'start',[1, start_val(2)]);
      end
    % ---------------------------------------------------------------------
      
    elseif val_choice == 2
      % get handle form 'axes' with 'tag' '*temp_iter2' and '*temp_exakt' 
      h_axes_iter  = gui_handle_query(axes_han,'tag','*temp_iter2'); 
      h_axes_verl  = gui_handle_query(axes_han,'tag','*temp_verlauf');
      tag_iter2   = get(h_axes_iter,'tag');
      tag_verlauf = get(h_axes_verl,'tag');
     
      axes(h_axes_iter);
      eval(ev_str1);          % ausfuehren des Graphikplots z.B. h_p = surf(X,Y,T_iter); h_cb = colorbar;
      eval(ev_str_col);       % ausfuehren 'colormap(...)'
      eval(ev_str_shad);      % ausfuehren 'shading ...'
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Temperature iterated','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{iter} / C','fontsize',12);
      
      h_p=reshape(h_p,1,[]);
      gui_set_userdata(h_axes_iter,'handles_plot',[h_p h_cb]);
      
      axes(h_axes_verl);
      eval(ev_str1);          % ausfuehren des Graphikplots z.B. h_p = surf(X,Y,T_iter); h_cb = colorbar;
      eval(ev_str_col);       % ausfuehren 'colormap(...)'
      eval(ev_str_shad);      % ausfuehren 'shading ...'
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Process of iteration','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{iter} / C','fontsize',12);
      
      h_p=reshape(h_p,1,[]);
      gui_set_userdata(h_axes_verl,'handles_plot',[h_p h_cb]);
      
      % speichern der 'plot' Daten fuer die Umschaltung der einzelnen Graphikoptionen!
      gui_set_userdata(h_axes_iter, 'x_sol',X);
      gui_set_userdata(h_axes_iter, 'y_sol',Y);
      gui_set_userdata(h_axes_iter, 'z_sol',T_iter);
     
      % set 'tag's of the 'axes'
      set(h_axes_iter,'tag',tag_iter2);
      set(h_axes_verl,'tag',tag_verlauf);
      
      % Setze userdata von 'start' auf 1
      h_start = gui_handle_query(uicontrol_han,'tag','*start');
      start_val = gui_get_userdata(h_start,'start');  % beim ersten mal ist start_val = [0, 0]
      if ~start_val(2)
        gui_set_userdata(h_start,'start',[start_val(1), 1]);
      end
    end
  
    
   % haelt die 'enable' uicontrols update   
    gui_set_userdata(stop_han,'stop',0);
    set(stop_han,'enable','off');
    enable_status = gui_get_userdata(gcbo,'enable_status');
    for k = 1:length(disable_han)
      set(disable_han(k),'enable',enable_status{k});
    end
    % ======================================================================
   
  case 'stop'
    % stop
    % ======================================================================
    stop_han = gui_handle_query(HANDLE.uicontrol,'tag','*stop');    
    gui_set_userdata(stop_han,'stop',1);
    % ======================================================================  
  case 'berechnungsmodus'
    % Schaltet zwischen den Optionen 'Testbeispiel' und
    % 'bel. Randbedingungen' um
    axes_han = HANDLE.axes;
    uicontrol_han = HANDLE.uicontrol;
    lin_han = HANDLE.line;
    h_start = gui_handle_query(uicontrol_han,'tag','*start');
    start_val = gui_get_userdata(h_start,'start');
    h_axes_reg2   = gui_handle_query(axes_han,'tag','*temp_gebiet2*');
    h_text_reg2 = gui_get_userdata(h_axes_reg2,'text_handle');
    
    pop_value = get(gcbo,'value');  % 1...Testbeispiel, 2...bel. Randbed.
    if pop_value == 1
      h_sli_delay = gui_handle_query(uicontrol_han,'tag','*delay*');
      h_tog       = gui_handle_query(uicontrol_han,'tag','*display_iter*');
      set([h_sli_delay, h_tog],'enable','off');
      h_axes1 = gui_handle_query(axes_han,'tag','*result*');
      h_axes2 = gui_handle_query(axes_han,'tag','*result_bound*');
      set(h_axes1,'visible','on');    % 'Testimonial'
      set(h_axes2,'visible','off');   % 'Any boundary cond.'
      h_set    = gui_handle_query(uicontrol_han,'tag','*Set_boundary');
      h_interp = gui_handle_query(uicontrol_han,'tag','*Interpolation');
      set([h_set,h_interp],'enable','off');
      if start_val(1)
        h_clear = gui_handle_query(uicontrol_han,'tag','*Clear_deviation');
        set(h_clear,'enable','on');
      end
      
      %lin_han = gui_handle_query(lin_han,'parent',ax_han); 
      h_reg   = gui_handle_query(lin_han,'tag','*region2');
      h_delim = gui_handle_query(lin_han,'tag','*delim2');
      h_verlauf = gui_handle_query(lin_han,'tag','*tempbound');
      h_points = gui_handle_query(lin_han,'tag','*temppoints');
      h_max  = gui_handle_query(lin_han,'tag','*tempmax');
      h_av = gui_handle_query(lin_han,'tag','*tempmittel');
      set([h_reg h_delim h_verlauf h_points], 'visible', 'off');
      set([h_max h_av],'visible', 'on');
      % set 'text' of region2 invisible
      set(h_text_reg2,'visible','off');
      % 3D Plots und Colorbar werden sichtbar gemacht (Testimonial)
      h_axes_iter1 = gui_handle_query(axes_han,'tag','*temp_iter1');
      h_axes_exakt = gui_handle_query(axes_han,'tag','*temp_exakt');
      h_axes_diff  = gui_handle_query(axes_han,'tag','*temp_diff');
      if start_val(1)
        h_p1_cb1 = gui_get_userdata(h_axes_iter1,'handles_plot');
        h_p2_cb2 = gui_get_userdata(h_axes_exakt,'handles_plot');
        h_p3_cb3 = gui_get_userdata(h_axes_diff,'handles_plot');
        set([h_p1_cb1, h_p2_cb2, h_p3_cb3],'visible','on');
      end
      % 3D Plots und Colorbar werden unsichtbar gemacht (Any boundary cond.)
      
      h_axes_iter2 = gui_handle_query(axes_han,'tag','*temp_iter2');
      h_axes_verl  = gui_handle_query(axes_han,'tag','*temp_verlauf');
      if start_val(2) %start_val(2) gibt an ob schon einmal ein 'plot' durchgefuehrt wurde!
	h_p4_cb4 = gui_get_userdata(h_axes_iter2,'handles_plot');
	h_p5_cb5 = gui_get_userdata(h_axes_verl,'handles_plot');
	set([h_p4_cb4, h_p5_cb5],'visible','off');
      end
      
      stop_han = gui_handle_query(uicontrol_han,'tag','*stop');    
      disable_han = uicontrol_han(uicontrol_han~=stop_han);
      enable_status = {get(disable_han,'enable')};
      gui_set_userdata(gcbo,'enable_status',enable_status);
      % set 'uicontrols' visible or invisible
    elseif pop_value == 2
      % set 'uicontrols' visible or invisible
      h_sli_delay = gui_handle_query(uicontrol_han,'tag','*delay*');
      h_tog = gui_handle_query(uicontrol_han,'tag','*display_iter*');
      set(h_tog,'enable','on');
      tog_val = get(h_tog,'value');
      if tog_val
	set(h_sli_delay,'enable','on');
      end
      h_axes1 = gui_handle_query(axes_han,'tag','*result*');
      h_axes2 = gui_handle_query(axes_han,'tag','*result_bound*');
      set(h_axes1,'visible','off');
      set(h_axes2,'visible','on');
      h_set = gui_handle_query(uicontrol_han,'tag','*Set_boundary');
      h_interp = gui_handle_query(uicontrol_han,'tag','*Interpolation');
      set([h_set, h_interp],'enable','on');
      h_clear = gui_handle_query(uicontrol_han,'tag','*Clear_deviation');
      set(h_clear,'enable','off');
      
      % ----------------------------------------------------------------------
      % Testimonial
      % 3D Plots und Colorbar werden unsichtbar gemacht 
      h_axes_iter  = gui_handle_query(axes_han,'tag','*temp_iter1');
      h_axes_exakt = gui_handle_query(axes_han,'tag','*temp_exakt');
      h_axes_diff = gui_handle_query(axes_han,'tag','*temp_diff');
      if start_val(1)
        h_p1_cb1 = gui_get_userdata(h_axes_iter,'handles_plot');
        h_p2_cb2 = gui_get_userdata(h_axes_exakt,'handles_plot');
        h_p3_cb3 = gui_get_userdata(h_axes_diff,'handles_plot');
        set([h_p1_cb1, h_p2_cb2, h_p3_cb3],'visible','off');
      end
      % 3D Plots und Colorbar werden sichtbar gemacht (Any boundary cond.)
      h_axes_iter2 = gui_handle_query(axes_han,'tag','*temp_iter2');
      h_axes_verl  = gui_handle_query(axes_han,'tag','*temp_verlauf');
      if start_val(2)
	h_p4_cb4 = gui_get_userdata(h_axes_iter2,'handles_plot');
	h_p5_cb5 = gui_get_userdata(h_axes_verl,'handles_plot');
	set([h_p4_cb4, h_p5_cb5],'visible','on');
      end
     
      % 'line' from 'deviation' set invisible
      h_av = gui_handle_query(lin_han,'tag','*tempmittel');
      h_max  = gui_handle_query(lin_han,'tag','*tempmax');
      set([h_max, h_av],'visible', 'off');
      % -----------------------------------------------------------------------
      
      % 'line' from 'region2' and 'boundary' set visible
      h_reg   = gui_handle_query(lin_han,'tag','*region2');
      h_delim = gui_handle_query(lin_han,'tag','*delim2');
      h_verlauf   = gui_handle_query(lin_han,'tag','*tempbound');
      h_points = gui_handle_query(lin_han,'tag','*temppoints');
      set([h_reg, h_delim, h_verlauf, h_delim, h_points], 'visible', 'on');
      % set 'text' of region2 invisible
      set(h_text_reg2,'visible','on');
      
      % haelt die 'enable' uicontrols update
      stop_han = gui_handle_query(uicontrol_han,'tag','*stop');    
      disable_han = uicontrol_han(uicontrol_han~=stop_han);
      enable_status = {get(disable_han,'enable')};
      gui_set_userdata(gcbo,'enable_status',enable_status);
    end 
   
  case 'setup_line'    
    % set 'line' first time    
    axes_han   = HANDLE.axes;
    h_axes_geb   = gui_handle_query(axes_han,'tag','*temp_gebiet1*');
    axes(h_axes_geb);
    grid on
    R = 4; % Radius des Halbkreises und Seitenlaenge de Quadrates
    xg = [R, R, 0, 0, -R]; yg = [0, -R, -R, 0, 0];
    xhk = -R:0.05:R;  yhk = sqrt(R^2 - xhk.^2);
    
        
    set(gca,'xlim',1.125*[-R R],'ylim',1.125*[-R R]);
    title('Region of calculation','fontsize',12);
    xlabel('x','fontsize',10);
    ylabel('y','fontsize',10);
    lin_han = HANDLE.line;
    lin_han = gui_handle_query(lin_han,'parent',h_axes_geb); 
    h_reg   = gui_handle_query(lin_han,'tag','*region1');
    h_delim = gui_handle_query(lin_han,'tag','*delim1');
 
    set(h_reg,    'xdata',[xg xhk], 'ydata',[yg yhk]);
    set(h_delim,  'xdata',xg,       'ydata',yg);
    text(3.0,0.0,  'A', 'horizontalalignment','left',   'fontsize',10)
    text(-3.3,0.4, 'B', 'horizontalalignment','right',  'fontsize',10)
    text(0.0,0.0,  'C', 'verticalalignment',   'bottom','fontsize',10)
    text(0.2,-3.5, 'D', 'horizontalalignment', 'left',  'fontsize',10)
    text(3.7,-3.5, 'E', 'horizontalalignment', 'right', 'fontsize',10)
    % ---------------------------------------------------------------------
    % draw lines (region2)
    h_axes_geb   = gui_handle_query(axes_han,'tag','*temp_gebiet2*');
    axes(h_axes_geb);
    grid on
    
    xhk_delim = R*[1/sqrt(2), 0, -1/sqrt(2)];
    yhk_delim = R*[1/sqrt(2), 1, 1/sqrt(2)];
    xg_delim = R*[-1/2 0 1/2 1]; yg_delim = R*[0 -1/2 -1 -1/2];
    set(gca,'xlim',1.125*[-R R],'ylim',1.125*[-R R]);
    title('Region of calculation','fontsize',12);
    xlabel('x','fontsize',10);
    ylabel('y','fontsize',10);
    lin_han = HANDLE.line;
    lin_han = gui_handle_query(lin_han,'parent',h_axes_geb); 
    h_reg   = gui_handle_query(lin_han,'tag','*region2');
    h_delim = gui_handle_query(lin_han,'tag','*delim2');
 
    set(h_reg,    'xdata',[xg xhk],                'ydata',[yg yhk]);
    set(h_delim,  'xdata',[xg xhk_delim xg_delim], 'ydata',[yg  yhk_delim yg_delim]);
    % damit diese 'line' die vorherig nicht berzeichnet! Muss beim
    % Umschalten in berechnungsmodus' wieder sichtbar gemacht werden!
    h_text(1)  = text( 3.8, 0.0,     '1',   'horizontalalignment','right', 'fontsize',10);
    h_text(2)  = text( 2.3, 2.3,     '2',   'horizontalalignment','left',  'fontsize',10);
    h_text(3)  = text( 0.0, 3.8,     '3',   'verticalalignment',  'top',   'fontsize',10);
    h_text(4)  = text(-2.3, 2.3,     '4',   'horizontalalignment','right', 'fontsize',10);   
    h_text(5)  = text(-3.7, 0.4,     '5',   'horizontalalignment','left',  'fontsize',10);
    h_text(6)  = text(-2.2, 0.1,     '6',   'verticalalignment',  'bottom','fontsize',10);
    h_text(7)  = text( 0.0, 0.1,     '7',   'verticalalignment',  'bottom','fontsize',10);
    h_text(8)  = text( 0.3,-2.0,     '8',   'horizontalalignment','left',  'fontsize',10);
    h_text(9)  = text( 0.3,-3.7,     '9',   'horizontalalignment','left',  'fontsize',10);
    h_text(10) = text( 1.5,-3.8,    '10',   'verticalalignment',  'bottom','fontsize',10);
    h_text(11) = text( 3.8,-3.7,    '11',   'horizontalalignment','right', 'fontsize',10);
    h_text(12) = text( 3.8,-2.0,    '12',   'horizontalalignment','right', 'fontsize',10);
    set(h_reg,   'visible', 'off'); 
    set(h_delim, 'visible', 'off');
    set(h_text,  'visible', 'off');
    gui_set_userdata(gca,'text_handle',h_text);
    % ---------------------------------------------------------------------
    % draw lines (boundary conditions)
    h_axes_bound = gui_handle_query(axes_han,'tag','*bound_cond*');
    axes(h_axes_bound);
    grid on
    xbound_hk = (0:R*pi/4:R*pi)+1;
    xbound_qd = R*pi+R/2+1:R/2:4*R+R*pi;
    xbound = [xbound_hk, xbound_qd];
    ybound = 1100*rand(1,12)-100;   % erzeugt Zufallszahlen zw. -100 und 1000 (C)!
    
    set(gca,'xlim',[0 30],'ylim',1.2*[-100, 1000]);
    title('Boundary Condition','fontsize',12);
    xlabel('Points # on boundary','fontsize',10);
    ylabel('Temperature T / C','fontsize',10);
    
    lin_han = HANDLE.line;
    lin_han = gui_handle_query(lin_han,'parent',h_axes_bound); 
    h_bound = gui_handle_query(lin_han,'tag','*tempbound');
    h_delim = gui_handle_query(lin_han,'tag','*temppoints');
    xticklab = {'1';'2';'3';'4';'5';'6';'7';'8';'9';'10';'11';'12'};
    
    set(h_axes_bound,'xtickmode',     'manual',  ...
	             'XTickLabelMode','manual', ...
	  	     'xtick',         [xbound_hk xbound_qd], ...
	 	     'xticklabel',    xticklab, ...
                     'ytick',         [-100, 0:200:1200]  );
    set(h_bound,  'xdata',xbound, 'ydata',ybound);  
    set(h_delim, 'xdata',xbound, 'ydata',ybound);
    
    set(h_bound,  'visible', 'off');  
    set(h_delim,  'visible', 'off');
   
  % ======================================================================
  case 'plotmodus_3d'
    uicontrol_han = HANDLE.uicontrol;
    axes_han = HANDLE.axes;
    h_pop_choice = gui_handle_query(uicontrol_han,'tag','*berech_modus');
    val_choice = get(h_pop_choice,'value');
    h_start = gui_handle_query(uicontrol_han,'tag','*start');
    start_val = gui_get_userdata(h_start,'start');
   
    h_pop_plotmode = gui_handle_query(uicontrol_han,'tag','*3Dplotmod');
    plot3d_nr = get(h_pop_plotmode,'value');
    plot3d_style_str = gui_get_userdata(h_pop_plotmode,'plotstyle_3d');
    
    
    if val_choice == 1 & start_val(1)
      h_axes_iter  = gui_handle_query(axes_han,'tag','*temp_iter1');
      h_axes_exakt = gui_handle_query(axes_han,'tag','*temp_exakt');
      h_axes_diff = gui_handle_query(axes_han,'tag','*temp_diff');

      tag_iter = get(h_axes_iter,'tag');
      tag_exakt = get(h_axes_exakt,'tag');
      tag_diff = get(h_axes_diff,'tag');
     % keyboard
      % Holt die x, y, und z Daten, die im 'handle' der 'plots'
      % gespeichert sind!
      X = gui_get_userdata(h_axes_iter,'x_sol');
      Y = gui_get_userdata(h_axes_iter,'y_sol');
      T_iter = gui_get_userdata(h_axes_iter,  'z_sol');
      T_exakt = gui_get_userdata(h_axes_exakt,'z_sol');
      T_diff = gui_get_userdata(h_axes_diff,  'z_sol');
      
      
      ev_str1 = strrep(plot3d_style_str(plot3d_nr,:),'##','T_iter');
      ev_str2 = strrep(plot3d_style_str(plot3d_nr,:),'##','T_exakt');
      ev_str3 = strrep(plot3d_style_str(plot3d_nr,:),'##','T_diff');
      %keyboard
      % Plot wird entsprechend des Modus umgewandelt
      axes(h_axes_iter);
      eval(ev_str1);
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Temperature iterated','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{iter} / K','fontsize',12);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p = reshape(h_p,1,[]);
      gui_set_userdata(h_axes_iter, 'handles_plot',[h_p h_cb]);
      
      axes(h_axes_exakt);
      eval(ev_str2);
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Temperature analytical','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{exact} / K','fontsize',12);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p = reshape(h_p,1,[]);
      gui_set_userdata(h_axes_exakt,'handles_plot',[h_p h_cb]);
      
      axes(h_axes_diff);
      eval(ev_str3);
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Difference of temperatures','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('\DeltaT / K','fontsize',12);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p = reshape(h_p,1,[]);
      gui_set_userdata(h_axes_diff, 'handles_plot',[h_p h_cb]);
      
      set(h_axes_iter, 'tag',tag_iter);
      set(h_axes_exakt,'tag',tag_exakt);
      set(h_axes_diff, 'tag',tag_diff);
      gui_set_userdata(h_axes_iter,  'x_sol',X);
      gui_set_userdata(h_axes_iter,  'y_sol',Y);
      gui_set_userdata(h_axes_iter,  'z_sol',T_iter);
      gui_set_userdata(h_axes_exakt, 'z_sol',T_exakt);
      gui_set_userdata(h_axes_diff,  'z_sol',T_diff);
      % Selbstaufruf der Funktion 'temp_vert shading3d', um das richtige
      % Schattierung der Plots einzustellen!
      eval( [func_name,' ''color_3d'''] );
      eval( [func_name,' ''shading_3d'''] ); 
      
    elseif val_choice == 2 & start_val(2)
      h_axes_iter = gui_handle_query(axes_han,'tag','*temp_iter2');
      h_axes_verl = gui_handle_query(axes_han,'tag','*temp_verlauf');

      tag_iter = get(h_axes_iter,'tag');
      tag_verl = get(h_axes_verl,'tag');
     
     % keyboard
      % Holt die x, y, und z Daten, die im 'handle' der 'plots'
      % gespeichert sind!
      
      X = gui_get_userdata(h_axes_iter,'x_sol');
      Y = gui_get_userdata(h_axes_iter,'y_sol');
      T_iter = gui_get_userdata(h_axes_iter,  'z_sol');
     
      
      ev_str = strrep(plot3d_style_str(plot3d_nr,:),'##','T_iter');
     
      axes(h_axes_iter);
      eval(ev_str);
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Temperature iterated','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{iter} / K','fontsize',12);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p = reshape(h_p,1,[]);
      gui_set_userdata(h_axes_iter, 'handles_plot',[h_p h_cb]);
      
      axes(h_axes_verl);
      eval(ev_str);
      set(h_p,...
	  'buttondownfcn',...
	  'rotate3d on; waitforbuttonpress; waitforbuttonpress; rotate3d off');
      title('Process of iteration','fontsize',12);
      xlabel('x','fontsize',12);
      ylabel('y','fontsize',12);
      zlabel('T_{iter} / K','fontsize',12);
      % handles zum 'plot' und zur 'colorbar' muessen gespeichert werden,
      % um sie beim Umschalten zum anderen 'Berechnungsmodus'
      % auszublenden
      h_p = reshape(h_p,1,[]);
      gui_set_userdata(h_axes_verl, 'handles_plot',[h_p h_cb]);
      
      set(h_axes_iter,'tag',tag_iter);
      set(h_axes_verl, 'tag',tag_verl);
      gui_set_userdata(h_axes_iter,  'x_sol',X);
      gui_set_userdata(h_axes_iter,  'y_sol',Y);
      gui_set_userdata(h_axes_iter,  'z_sol',T_iter);
      % Selbstaufruf der Funktion 'temp_vert shading3d', um das richtige
      % Schattierung der Plots einzustellen!
      eval( [func_name,' ''color_3d'''] );
      eval( [func_name,' ''shading_3d'''] );
    end
  
  case 'shading_3d'
    axes_han = HANDLE.axes;
    uicontrol_han = HANDLE.uicontrol;
    % 'brechnungsmodus' data
    h_pop_choice = gui_handle_query(uicontrol_han,'tag','*berech_modus');
    val_choice = get(h_pop_choice,'value');
    h_start = gui_handle_query(uicontrol_han,'tag','*start');
    start_val = gui_get_userdata(h_start,'start'); 
    % Plotmode data
    h_pop_plotmode = gui_handle_query(uicontrol_han,'tag','*3Dplotmod');
    p3d_nr = get(h_pop_plotmode,'value');
    p3d_str = gui_get_userdata(h_pop_plotmode,'plotstyle_3d');
    % get data form 'popup' 'Shading 3D'
    h_pop_shad = gui_handle_query(uicontrol_han,'tag','*3Dshading');
    shad_nr = get(h_pop_shad,'value');
    shad_str = gui_get_userdata(h_pop_shad,'shading');
    if ~isempty(findstr(p3d_str(p3d_nr,:),'contourf'))
      ev_str_shad = shad_str(1,:);   % facted
      set(h_pop_shad,'value',1);
    else
      ev_str_shad = shad_str(shad_nr,:);
    end
    
    if val_choice == 1 & start_val(1)
      h_axes_iter  = gui_handle_query(axes_han,'tag','*temp_iter1');
      h_axes_exakt = gui_handle_query(axes_han,'tag','*temp_exakt');
      h_axes_diff = gui_handle_query(axes_han,'tag','*temp_diff');
      axes(h_axes_iter);
      eval(ev_str_shad);
      axes(h_axes_exakt);
      eval(ev_str_shad);
      axes(h_axes_diff);
      eval(ev_str_shad);
    elseif val_choice == 2 & start_val(2)
      h_axes_iter = gui_handle_query(axes_han,'tag','*temp_iter2');
      h_axes_verl = gui_handle_query(axes_han,'tag','*temp_verlauf');
      axes(h_axes_iter);
      eval(ev_str_shad);
      axes(h_axes_verl);
      eval(ev_str_shad);
    end
  
  case 'color_3d'
    axes_han = HANDLE.axes;
    uicontrol_han = HANDLE.uicontrol;
    h_pop_choice = gui_handle_query(uicontrol_han,'tag','*berech_modus');
    val_choice = get(h_pop_choice,'value');
    h_start = gui_handle_query(uicontrol_han,'tag','*start');
    start_val = gui_get_userdata(h_start,'start');
    % get handle form 'popup' 'Color 3D'
    h_pop_col = gui_handle_query(uicontrol_han,'tag','*3Dcolor');
   % keyboard
    col_nr = get(h_pop_col,'value');
    col_str = gui_get_userdata(h_pop_col,'color_3d');
    ev_str_col = col_str(col_nr,:);
    
    if val_choice == 1 & start_val(1)
      h_axes_iter  = gui_handle_query(axes_han,'tag','*temp_iter1');
      h_axes_exakt = gui_handle_query(axes_han,'tag','*temp_exakt');
      h_axes_diff = gui_handle_query(axes_han,'tag','*temp_diff');
     
      axes(h_axes_iter);
      eval(ev_str_col);
      axes(h_axes_exakt);
      eval(ev_str_col);
      axes(h_axes_diff);
      eval(ev_str_col);
    elseif val_choice == 2 & start_val(2)
      h_axes_iter = gui_handle_query(axes_han,'tag','*temp_iter2');
      h_axes_verl = gui_handle_query(axes_han,'tag','*temp_verlauf');
      axes(h_axes_iter);
      eval(ev_str_col);
      axes(h_axes_verl);
      eval(ev_str_col);
    end
    
  case 'clear_deviation'
    % loescht die 'xdata' und 'ydata' von 'line'-deviation
    axes_han = HANDLE.axes;
    lin_han = HANDLE.line;
    h_axes_av = gui_handle_query(axes_han,'tag','*temp_mittel_diff');
    lin_han = gui_handle_query(lin_han,'parent',h_axes_av); 
    h_max  = gui_handle_query(lin_han,'tag','*tempmax');
    h_av = gui_handle_query(lin_han,'tag','*tempmittel');
    set(h_max,'xdata',[],'ydata',[]);
    set(h_av,'xdata',[],'ydata',[]);
    drawnow;
  
  case 'relax_par'
    uicontrol_han = HANDLE.uicontrol;
    h_edit_rel = gui_handle_query(uicontrol_han,'tag','*relax_par');
    w = str2num(get(h_edit_rel,'string'));
    % Stellt sicher, dass w keine 'strings' enthaelt und nicht groesser
    % als 2 bzw. kleiner als 1 ist
    if isempty(w)
      set(h_edit_rel,'string','')
    elseif ((w > 2) | (w < 1))
      set(h_edit_rel,'string','1')
    end  
  case 'display_iter'  
    uicontrol_han = HANDLE.uicontrol;
    h_tog_disp = gui_handle_query(uicontrol_han,'tag','*display_iter');
    h_sli_delay = gui_handle_query(uicontrol_han,'tag','*delay slider*');
    val_tog = get(h_tog_disp,'value');
    if val_tog == 0
      set(h_tog_disp,'string','Display iter. OFF');
      set(h_sli_delay,'enable','off');
    elseif val_tog == 1
      set(h_tog_disp,'string','Display iter. ON');
      set(h_sli_delay,'enable','on');
    end
  
  case 'set_boundary'
    fig_han = HANDLE.figure;
    uicontrol_han = HANDLE.uicontrol;
    axes_han = HANDLE.axes;
    lin_han = HANDLE.line;
    h_bound_line = gui_handle_query(lin_han,'tag','*tempbound');
    h_bound_mark = gui_handle_query(lin_han,'tag','*temppoints'); 
    h_axes_bound = gui_handle_query(axes_han,'tag','*bound_cond');								  
    fig_han = gui_handle_query(fig_han,'tag',['*main']);								
    func_name = gui_get_userdata(fig_han,'function'); % function name
    % randomly generate bondary condition
    temp_bound = 1100*rand(1,12)-100;
    set(h_bound_mark,'ydata',temp_bound);
    % calls the function 'temp_vert interpolation', to calculate the curve through
    % the points
    eval( [func_name,' ''interpolation'''] );
    % in addition one can set the boundary condition manually
    set(h_axes_bound,'buttondownfcn','set_data');
    gui_add_name(h_axes_bound,func_name,' ','b','buttondownfcn');
   
  case 'interpolation'
    uicontrol_han = HANDLE.uicontrol;
    lin_han  = HANDLE.line;
    h_bound_line = gui_handle_query(lin_han,'tag','*tempbound');
    h_bound_mark = gui_handle_query(lin_han,'tag','*temppoints');
    
    temp_bound= get(h_bound_mark,'ydata');
    l_bound = get(h_bound_mark,'xdata');
    
    x = l_bound(1):0.05:l_bound(end);  % Interpolationsstuetzpunkte
    h_pop_interp = gui_handle_query(uicontrol_han,'tag','*Interpolation');
    interp_val = get(h_pop_interp,'value');
   % keyboard
    if interp_val == 1
      set(h_bound_line,'xdata',l_bound,'ydata',temp_bound);
    elseif interp_val == 2
      y = interp1(l_bound,temp_bound,x,'pchip');
      set(h_bound_line,'xdata',x,'ydata',y);
    end
   % keyboard
  case 'set_data'
    % set data with mouse
    axes_han = HANDLE.axes;
    lin_han = HANDLE.line;
    h_axes_bound = gui_handle_query(axes_han,'tag','*bound_cond');
    h_bound_mark = gui_handle_query(lin_han,'tag','*temppoints');
    % x- und y-data
    l_bound = get(h_bound_mark,'xdata');
    temp_bound = get(h_bound_mark,'ydata');
    % get positon within the axes of the 'handle' h_axes_bound
    pos = get(h_axes_bound,'currentpoint');
    xpos = pos(1,1);
    ypos = pos(1,2);
    if ypos > 1100
      ypos = 1100;
    elseif ypos < -100
      ypos = -100;
    end
    dx = abs(l_bound - xpos);
    index = find(min(dx)==dx);
    temp_bound(index) = ypos;
    set(h_bound_mark,'ydata',temp_bound);
    eval( [func_name,' ''interpolation'''] );
  
  otherwise
    % ======================================================================
    % warnings if callback routine is not defined (keep this at the end)    
    % ======================================================================
    disp(['Callback not defined: ',action]);
    % ======================================================================

end









